Learn R Programming

vermeulen (version 0.1.1)

vermeulen-package: vermeulen: 'Biomarker' Data Set by Vermeulen et al. (2009)

Description

The 'biomarker' data set by Vermeulen et al. (2009) tools:::Rd_expr_doi("10.1016/S1470-2045(09)70154-8") is provided. The data source, however, is by Ruijter et al. (2013) tools:::Rd_expr_doi("10.1016/j.ymeth.2012.08.011"). The original data set may be downloaded from https://medischebiologie.nl/wp-content/uploads/2019/02/qpcrdatamethods.zip. This data set is for a real-time quantitative polymerase chain reaction ('PCR') experiment that comprises the raw fluorescence data of 24,576 amplification curves. This data set comprises 59 genes of interest and 5 reference genes. Each gene was assessed on 366 neuroblastoma complementary DNA ('cDNA') samples and on 18 standard dilution series samples (10-fold 5-point dilution series x 3 replicates + no template controls ('NTC') x 3 replicates).

Arguments

Author

Maintainer: Ramiro Magno ramiro.magno@gmail.com (ORCID)

Other contributors:

  • Pattern Institute [copyright holder, funder]

See Also